//项目名称：GO_GTD2
//by:jsxyhelu.cnblogs.com
//最后更新: 2018年1月26日
import QtQuick 2.9
import QtQuick.Window 2.2
import QtQuick.Layouts 1.0
import QtQuick.Controls 2.2
import Qt.labs.settings 1.0
import QtMultimedia 5.8
import com.amin.classes 1.0

ApplicationWindow {
    visible: true
    width: 640
    height: 480
    title: qsTr("GO_GTD2")


    //主要的图像处理类
    CvImageProcessor
    {
        id: imageProcessor

        onErrorOccured:
        {
            messageDialog.title = qsTr("Error")
            messageDialog.text = msg
            messageDialog.open()
        }
        //处理完成
        onImageProcessed:
        {
            imageViewer.source = "file:///" + fname
            messageDialog.title = qsTr("图片保存完成")
            messageDialog.text = "File : " + fname + "<br><br>切换到 <a href=\"图像处理\">图像处理界面</a>查看结果."
            messageDialog.open()
        }
    }

    /*
        只有一个OK的弹出界面,目前这个弹出界面只给捕获的时候使用
    */
    Dialog
    {
        property alias text: msgDlgLabel.text
        id: messageDialog
        modal: true
        x: (parent.width - width) / 2
        y: (parent.height - height) / 2

        standardButtons: Dialog.Ok
        //上面只有一个label
        Label
        {
            id: msgDlgLabel
            font.bold: true
            wrapMode: Text.Wrap
            width: parent.width
            //点击事件
            onLinkActivated:
            {
                if(link == "图像处理")
                {
                    tabBar.currentIndex = 1
                }
                messageDialog.close()
            }
        }
    }

    /*
        主要的swipview界面
    */
    SwipeView
    {
        id: swipeView
        currentIndex: 0
        anchors.rightMargin: 0
        anchors.bottomMargin: 0
        anchors.leftMargin: 0
        anchors.topMargin: 0
        anchors.fill: parent
        //TabBar和swipview要对应起来
        onCurrentIndexChanged:
        {
            tabBar.setCurrentIndex(swipeView.currentIndex)
        }

        //视频预览
        Page
        {
            ColumnLayout
            {
                anchors.fill: parent
                GroupBox
                {
                    title: qsTr("视频预览")
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    Layout.margins: 10

                    VideoOutput
                    {
                        id: videoOutput
                        anchors.fill: parent
                        Camera
                        {
                            id: camera
                            Component.onCompleted:
                            {
                                imageProcessor.setCamera(camera)
                            }
                        }
                        source: camera
                        fillMode: Qt.KeepAspectRatio
                        autoOrientation: true
                        MouseArea
                        {
                            anchors.fill: parent
                            onReleased:
                            {
                                messageDialog.title = qsTr("提示")
                                messageDialog.text = qsTr("请稍后，图像处理需要一定时间。处理完成后程序将自动跳转……")
                                messageDialog.open()
                                imageProcessor.capture()
                            }
                        }
                    }
                 }

                RowLayout
                {
                    Layout.margins: 10
                    Label
                    {
                        text: qsTr("选择摄像头")
                        font.bold: true
                    }
                    //摄像头选择对话框
                    ComboBox
                    {
                        id: cameraCombo
                        Layout.fillWidth: true
                        Layout.fillHeight: true
                        model: QtMultimedia.availableCameras
                        textRole: "displayName"

                        delegate: ItemDelegate
                        {
                            text: modelData.displayName
                        }
                        onCurrentIndexChanged:
                        {
                            camera.stop()
                            camera.deviceId = model[currentIndex].deviceId
                            camera.start()
                        }
                    }
              }

            }


        }
        //图像处理
        Page
        {
            ColumnLayout
            {
                anchors.fill: parent
                GroupBox
                {
                    title: qsTr("图像处理")
                    Layout.margins: 10
                    Layout.fillHeight: true
                    Layout.fillWidth: true

                    Image
                    {
                        id: imageViewer
                        fillMode: Qt.KeepAspectRatio
                        anchors.fill: parent
                    }
                }
                //这里不仅是界面修改，整个算法处理机制都要修改
                RowLayout
                {
                    Layout.margins: 10
                    Label
                    {
                        text: qsTr("选择算法")
                        font.bold: true
                    }

                    ComboBox
                    {
                        id: algorithmCombo
                        Layout.fillWidth: true
                        Layout.fillHeight: true
                        model: ListModel
                        {
                            //我特地拉长了前面，这样方便选择
                            ListElement { key: "不使用算法                                               "; value:  "none"}
                            ListElement { key: "灰度                                                    "; value:  "gray"}
                            ListElement { key: "二值                                                    "; value: "bit" }
                            ListElement { key: "Canny                                                  "; value: "canny" }
                        }
                        textRole: "key"
                        delegate: ItemDelegate
                        {
                            text: model.key
                        }

                        onCurrentIndexChanged:
                        {
                            imageProcessor.setAlgorithm(model.get(currentIndex).value)
                            tabBar.setCurrentIndex(0)
                            swipeView.setCurrentIndex(0)
                        }
                        //处理完成

                    }
                }

            }
        }
        //操作说明
        Page
        {
            ColumnLayout
            {
                anchors.fill: parent
                GroupBox
                {
                    title: qsTr("程序操作说明")
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    Layout.margins: 10
                    ColumnLayout
                    {
                        anchors.fill: parent
                        Flickable
                        {
                            id: flickable1
                            clip: true
                            Layout.fillHeight: true
                            Layout.fillWidth: true
                            contentWidth: parent.width
                            contentHeight: helpText.height
                            ScrollBar.vertical: ScrollBar
                            {
                                active: true
                            }
                            Text
                            {
                                id: helpText
                                wrapMode: Text.Wrap
                                anchors.left: parent.left
                                anchors.right: parent.right
                                text: "由衷感谢：<a href=\"http://amin-ahmadi.com/quick-camera-cv/\">http://amin-ahmadi.com/quick-camera-cv</a>" +
                                      "给本程序很多借鉴" +
                                      "<br>" +
                                      "<br>" +
                                      "作者博客:" +
                                      "<br>" +
                                      "<a href=\"jsxyhelu.cnblogs.com\">jsxyhelu.cnblogs.com</a>" +
                                      "<br>" +
                                      "<a href=\"jsxyhelu.cnblogs.com\"><img src=\"http://images2015.cnblogs.com/blog/508489/201607/508489-20160731065441684-483128601.png\"  alt=\"欢迎访问!\"></a>"+
                                      "<br>" +
                                      "<b>版权</b>" +
                                      "本程序使用 <a href=\"http://qt.io/\">Qt Framework</a> 作为GUI" +
                                      "<br>" +
                                      "同时使用 <a href=\"http://opencv.org/\">OpenCV</a> 做图像处理算法." +
                                      "<br>" +
                                      "程序采用ICO来自<a href=\"http://flaticon.com/\">Flat Icon</a>."
                                     onLinkActivated:
                                      {
                                           Qt.openUrlExternally(link); 
                                      }

                                }

                          }

                    }
                }
            }
        }

        Item {
        }

     }

    /*
        主要的footer操作
    */
    footer: TabBar {
        id: tabBar
        currentIndex: 0
        padding: 10

        //设置级联操作
        onCurrentIndexChanged:
        {
            swipeView.setCurrentIndex(tabBar.currentIndex)
        }

        TabButton {
            text: qsTr("视频预览")
             height: parent.height
        }
        TabButton {
            text: qsTr("图像处理")
             height: parent.height
        }
        TabButton {
            text: qsTr("操作说明")
             height: parent.height
        }


    }
}
